@@ -9,15 +9,17 @@ use strict;
 use warnings;
 use base qw( Tickit::Widget );
 use Tickit::Style;
-use Tickit::RenderContext;
+use Tickit::RenderBuffer;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Carp;
 
 use Tickit::Utils qw( textwidth );
 use List::MoreUtils qw( any );
 
+use constant CAN_FOCUS => 1;
+
 =head1 NAME
 
 C<Tickit::Widget::RadioButton> - a widget allowing a selection from multiple
@@ -99,6 +101,10 @@ style_definition ':active' =>
    b        => 1,
    tick     => "(*)";
 
+style_reshape_keys qw( spacing );
+
+style_reshape_textwidth_keys qw( tick );
+
 use constant WIDGET_PEN_FROM_STYLE => 1;
 
 =head1 CONSTRUCTOR
@@ -192,31 +198,6 @@ sub set_label
    $self->redraw;
 }
 
-sub on_style_changed_values
-{
-   my $self = shift;
-   my %values = @_;
-
-   foreach (qw( spacing )) {
-      next if !$values{$_};
-
-      $self->reshape;
-      $self->redraw;
-      return;
-   }
-
-   foreach (qw( tick )) {
-      next if !$values{$_};
-      next if textwidth( $values{$_}[0] ) == textwidth( $values{$_}[1] );
-
-      $self->reshape;
-      $self->redraw;
-      return;
-   }
-
-   $self->redraw;
-}
-
 =head1 METHODS
 
 =cut
@@ -261,28 +242,31 @@ sub render
    my %args = @_;
    my $win = $self->window or return;
 
-   my $rc = Tickit::RenderContext->new( lines => $win->lines, cols => $win->cols );
-   $rc->clip( $args{rect} );
-   $rc->setpen( $self->pen );
+   my $rb = Tickit::RenderBuffer->new( lines => $win->lines, cols => $win->cols );
+   $rb->clip( $args{rect} );
+   $rb->setpen( $self->pen );
 
-   $rc->clear;
+   $rb->clear;
 
-   $rc->goto( 0, 0 );
+   $rb->goto( 0, 0 );
 
-   $rc->text( $self->get_style_values( "tick" ), $self->get_style_pen( "tick" ) );
-   $rc->erase( $self->get_style_values( "spacing" ) );
-   $rc->text( $self->{label} );
-   $rc->erase_to( $win->cols );
+   $rb->text( my $tick = $self->get_style_values( "tick" ), $self->get_style_pen( "tick" ) );
+   $rb->erase( $self->get_style_values( "spacing" ) );
+   $rb->text( $self->{label} );
+   $rb->erase_to( $win->cols );
 
-   $rc->flush_to_window( $win );
+   $rb->flush_to_window( $win );
+
+   $win->cursor_at( 0, ( textwidth( $tick )-1 ) / 2 );
 }
 
 sub on_mouse
 {
    my $self = shift;
-   my ( $ev, $button, $line, $col ) = @_;
-   return unless $ev eq "press" and $button == 1;
-   return 1 unless $line == 0;
+   my ( $args ) = @_;
+
+   return unless $args->type eq "press" and $args->button == 1;
+   return 1 unless $args->line == 0;
 
    $self->activate;
 }
